==> Slicer3-3.0.2007-12-21-darwin-x86.tar.gz: Slicer3-3.0.2007-12-21-darwin-x86/lib/InsightToolkit/ITKConfig.cmake <==
#-----------------------------------------------------------------------------
#
# ITKConfig.cmake - ITK CMake configuration file for external projects.
#
# This file is configured by ITK and used by the UseITK.cmake module
# to load ITK's settings for an external project.

# The ITK source tree.
# For backward compatibily issues we still need to define this variable, although
# it is highly probable that it will cause more harm than being useful. 
# Use ITK_INCLUDE_DIRS instead, since ITK_SOURCE_DIR may point to non-existant directory
IF(NOT ITK_LEGACY_REMOVE)
  SET(ITK_SOURCE_DIR "/Users/hayes/Slicer3-release-gbt/Slicer3-lib/Insight")
ENDIF(NOT ITK_LEGACY_REMOVE)

# The ITK include file directories.
SET(ITK_INCLUDE_DIRS "/usr/local/include/InsightToolkit;/usr/local/include/InsightToolkit/Algorithms;/usr/local/include/InsightToolkit/BasicFilters;/usr/local/include/InsightToolkit/Common;/usr/local/include/InsightToolkit/expat;/usr/local/include/InsightToolkit/Numerics;/usr/local/include/InsightToolkit/IO;/usr/local/include/InsightToolkit/Numerics/FEM;/usr/local/include/InsightToolkit/Numerics/Statistics;/usr/local/include/InsightToolkit/Numerics/NeuralNetworks;/usr/local/include/InsightToolkit/SpatialObject;/usr/local/include/InsightToolkit/Utilities/MetaIO;/usr/local/include/InsightToolkit/Utilities/NrrdIO;/usr/local/include/InsightToolkit/Utilities/DICOMParser;/usr/local/include/InsightToolkit/Utilities/itkExtHdrs;/usr/local/include/InsightToolkit/Utilities;/usr/local/include/InsightToolkit/Utilities/vxl/vcl;/usr/local/include/InsightToolkit/Utilities/vxl/core;/usr/local/include/InsightToolkit/gdcm;/usr/local/include/InsightToolkit/gdcm/src")

# The ITK library directories.
SET(ITK_LIBRARY_DIRS "/usr/local/lib/InsightToolkit")

# The C and C++ flags added by ITK to the cmake-configured flags.
SET(ITK_REQUIRED_C_FLAGS " -w -no-cpp-precomp")
SET(ITK_REQUIRED_CXX_FLAGS " -ftemplate-depth-50 -no-cpp-precomp -Wno-long-double")
SET(ITK_REQUIRED_LINK_FLAGS "")

# The ITK version number
SET(ITK_VERSION_MAJOR "3")
SET(ITK_VERSION_MINOR "4")
SET(ITK_VERSION_PATCH "0")

# The location of the UseITK.cmake file.
SET(ITK_USE_FILE "/usr/local/lib/InsightToolkit/UseITK.cmake")

# The build settings file.
SET(ITK_BUILD_SETTINGS_FILE "/usr/local/lib/InsightToolkit/ITKBuildSettings.cmake")

# Whether ITK was built with shared libraries.
SET(ITK_BUILD_SHARED "ON")

# Whether ITK was built with Tcl wrapping support.
SET(ITK_CSWIG_TCL "OFF")
SET(ITK_CSWIG_PYTHON "OFF")
SET(ITK_CSWIG_JAVA "OFF")

# Path to CableSwig configuration used by ITK.
SET(ITK_CableSwig_DIR "")

# A list of all libraries for ITK.  Those listed here should
# automatically pull in their dependencies.
SET(ITK_LIBRARIES ITKAlgorithms ITKStatistics ITKFEM)

# The ITK library dependencies.
IF(NOT ITK_NO_LIBRARY_DEPENDS AND
    EXISTS "/usr/local/lib/InsightToolkit/ITKLibraryDepends.cmake")
  INCLUDE("/usr/local/lib/InsightToolkit/ITKLibraryDepends.cmake")
ENDIF(NOT ITK_NO_LIBRARY_DEPENDS AND
  EXISTS "/usr/local/lib/InsightToolkit/ITKLibraryDepends.cmake")

# Whether ITK was built using a system VXL or system gdcm or review
SET(ITK_USE_SYSTEM_VXL "OFF")
SET(ITK_USE_SYSTEM_GDCM "OFF")
SET(ITK_USE_REVIEW "OFF")

# The VXL_DIR setting used to build ITK.  Set if ITK_USE_SYSTEM_VXL is true.
# same for gdcm
SET(ITK_VXL_DIR "")
SET(ITK_GDCM_DIR "")

==> Slicer3-3.0.2008-01-17-darwin-x86.tar.gz: Slicer3-3.0.2008-01-17-darwin-x86/lib/InsightToolkit/ITKConfig.cmake <==
#-----------------------------------------------------------------------------
#
# ITKConfig.cmake - ITK CMake configuration file for external projects.
#
# This file is configured by ITK and used by the UseITK.cmake module
# to load ITK's settings for an external project.

# The ITK source tree.
# For backward compatibily issues we still need to define this variable, although
# it is highly probable that it will cause more harm than being useful. 
# Use ITK_INCLUDE_DIRS instead, since ITK_SOURCE_DIR may point to non-existant directory
IF(NOT ITK_LEGACY_REMOVE)
  SET(ITK_SOURCE_DIR "/Users/hayes/Slicer-3-0-release/Slicer3-lib/Insight")
ENDIF(NOT ITK_LEGACY_REMOVE)

# The ITK include file directories.
SET(ITK_INCLUDE_DIRS "/usr/local/include/InsightToolkit;/usr/local/include/InsightToolkit/Algorithms;/usr/local/include/InsightToolkit/BasicFilters;/usr/local/include/InsightToolkit/Common;/usr/local/include/InsightToolkit/expat;/usr/local/include/InsightToolkit/Numerics;/usr/local/include/InsightToolkit/IO;/usr/local/include/InsightToolkit/Numerics/FEM;/usr/local/include/InsightToolkit/Numerics/Statistics;/usr/local/include/InsightToolkit/Numerics/NeuralNetworks;/usr/local/include/InsightToolkit/SpatialObject;/usr/local/include/InsightToolkit/Utilities/MetaIO;/usr/local/include/InsightToolkit/Utilities/NrrdIO;/usr/local/include/InsightToolkit/Utilities/DICOMParser;/usr/local/include/InsightToolkit/Utilities/itkExtHdrs;/usr/local/include/InsightToolkit/Utilities;/usr/local/include/InsightToolkit/Utilities/vxl/vcl;/usr/local/include/InsightToolkit/Utilities/vxl/core;/usr/local/include/InsightToolkit/gdcm;/usr/local/include/InsightToolkit/gdcm/src")

# The ITK library directories.
SET(ITK_LIBRARY_DIRS "/usr/local/lib/InsightToolkit")

# The C and C++ flags added by ITK to the cmake-configured flags.
SET(ITK_REQUIRED_C_FLAGS " -w -no-cpp-precomp")
SET(ITK_REQUIRED_CXX_FLAGS " -ftemplate-depth-50 -no-cpp-precomp -Wno-long-double")
SET(ITK_REQUIRED_LINK_FLAGS "")

# The ITK version number
SET(ITK_VERSION_MAJOR "3")
SET(ITK_VERSION_MINOR "4")
SET(ITK_VERSION_PATCH "0")

# The location of the UseITK.cmake file.
SET(ITK_USE_FILE "/usr/local/lib/InsightToolkit/UseITK.cmake")

# The build settings file.
SET(ITK_BUILD_SETTINGS_FILE "/usr/local/lib/InsightToolkit/ITKBuildSettings.cmake")

# Whether ITK was built with shared libraries.
SET(ITK_BUILD_SHARED "ON")

# Whether ITK was built with Tcl wrapping support.
SET(ITK_CSWIG_TCL "OFF")
SET(ITK_CSWIG_PYTHON "OFF")
SET(ITK_CSWIG_JAVA "OFF")

# Path to CableSwig configuration used by ITK.
SET(ITK_CableSwig_DIR "")

# A list of all libraries for ITK.  Those listed here should
# automatically pull in their dependencies.
SET(ITK_LIBRARIES ITKAlgorithms ITKStatistics ITKFEM)

# The ITK library dependencies.
IF(NOT ITK_NO_LIBRARY_DEPENDS AND
    EXISTS "/usr/local/lib/InsightToolkit/ITKLibraryDepends.cmake")
  INCLUDE("/usr/local/lib/InsightToolkit/ITKLibraryDepends.cmake")
ENDIF(NOT ITK_NO_LIBRARY_DEPENDS AND
  EXISTS "/usr/local/lib/InsightToolkit/ITKLibraryDepends.cmake")

# Whether ITK was built using a system VXL or system gdcm or review
SET(ITK_USE_SYSTEM_VXL "OFF")
SET(ITK_USE_SYSTEM_GDCM "OFF")
SET(ITK_USE_REVIEW "OFF")

# The VXL_DIR setting used to build ITK.  Set if ITK_USE_SYSTEM_VXL is true.
# same for gdcm
SET(ITK_VXL_DIR "")
SET(ITK_GDCM_DIR "")
